# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from landing_page_server_connector.models.input_field import InputField

class ParsedForm(BaseModel):
    """
    ParsedForm
    """
    inputs: conlist(InputField) = Field(...)
    action: Optional[StrictStr] = None
    method: Optional[StrictStr] = None
    __properties = ["inputs", "action", "method"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParsedForm:
        """Create an instance of ParsedForm from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in inputs (list)
        _items = []
        if self.inputs:
            for _item in self.inputs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['inputs'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParsedForm:
        """Create an instance of ParsedForm from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParsedForm.parse_obj(obj)

        _obj = ParsedForm.parse_obj({
            "inputs": [InputField.from_dict(_item) for _item in obj.get("inputs")] if obj.get("inputs") is not None else None,
            "action": obj.get("action"),
            "method": obj.get("method")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "landing-page-server-connector"
VERSION = "0.2.1+2389563964"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil",
    "aiohttp >= 3.0.0",
    "pydantic >= 1.10.5, < 2",
    "aenum"
]

setup(
    name=NAME,
    version=VERSION,
    description="Mentortools Landing Page API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Mentortools Landing Page API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    Mentortools service for building and publishing landing pages
    """,  # noqa: E501
    package_data={"landing_page_server_connector": ["py.typed"]},
)
